import React from 'react';
import { BoxProps } from 'ink';
/**
 * Represent props of a <Tab>
 */
export interface TabProps {
    name: string;
    children: React.ReactNode;
}
/**
 * A <Tab> component
 */
declare const Tab: React.FunctionComponent<TabProps>;
/**
 * Declare how does the keyboard interacts with ink-tab here
 */
interface KeyMapProps {
    useNumbers?: boolean;
    useTab?: boolean;
    previous?: string[];
    next?: string[];
}
/**
 * Props for the <Tabs> component
 */
export interface TabsProps {
    /**
     * A function called whenever a tab is changing.
     * @param {string} name the name of the tab passed in the `name` prop
     * @param {React.Component<TabProps>} activeTab the current active tab component
     */
    onChange(name: string, activeTab: React.ReactElement<typeof Tab>): void;
    children: React.ReactElement<typeof Tab>[];
    flexDirection?: BoxProps['flexDirection'];
    width?: BoxProps['width'];
    keyMap?: KeyMapProps;
    isFocused?: boolean;
    defaultValue?: string;
    showIndex?: boolean;
}
/**
 * The <Tabs> component
 */
declare const Tabs: React.FunctionComponent<TabsProps>;
export { Tab, Tabs };
